@@ -8,7 +8,6 @@ __all__ = [
     'bits2bytes',
     'bits2integer',
     'byte2int',
-    'bytes',
     'bytes2bits',
     'bytes2integer',
     'bytes2integers',
@@ -33,6 +32,7 @@ __all__ = [
     'iteratebytes',
     'iterateints',
     'ListContainer',
+    'ONWINDOWS',
     'PY',
     'PY2',
     'PY3',
