@@ -1,26 +1,24 @@
-import sys
+import sys, platform
 
 PY = sys.version_info[:2]
 PY2 = sys.version_info[0] == 2
 PY3 = sys.version_info[0] == 3
 PYPY = '__pypy__' in sys.builtin_module_names
-
+ONWINDOWS = platform.system() == "Windows"
 
 stringtypes = (bytes, str, )
 integertypes = (int, )
 unicodestringtype = str
 bytestringtype = bytes
 
-
 INT2BYTE_CACHE = {i:bytes([i]) for i in range(256)}
 def int2byte(character):
     """Converts (0 through 255) integer into b'...' character."""
     return INT2BYTE_CACHE[character]
 
-BYTE2INT_CACHE = {bytes([i]):i for i in range(256)}
 def byte2int(character):
     """Converts b'...' character into (0 through 255) integer."""
-    return BYTE2INT_CACHE[character]
+    return character[0]
 
 def str2bytes(string):
     """Converts '...' string into b'...' string. On PY2 they are equivalent. On PY3 its utf8 encoded."""
@@ -58,5 +56,5 @@ def integers2bytes(ints):
     return bytes(ints)
 
 def bytes2integers(data):
-    """Converts bytes into bytes/bytearray, so indexing/iterating yields integers."""
-    return data
+    """Converts bytes into integer list, so indexing/iterating yields integers."""
+    return list(data)
